@@ -230,14 +230,14 @@ class Datatables(View):
             queryset = queryset.filter(reduce(operator.or_, self.search_value(search_value)))
         return queryset
 
-    def get_ordered_queryset(self, filters, search_value, order):
-        queryset = self.get_queryset(filters, search_value)
+    def get_ordered_queryset(self, filters, search_value, order, request):
+        queryset = self.get_queryset(filters, search_value, request)
         return queryset.order_by(order)
 
     def get_data(self, start, per_page, filters, search_value, draw, order=None, request=None):
         queryset = self.get_queryset(filters, search_value, request)
         if order:
-            queryset = self.get_ordered_queryset(filters, search_value, order)
+            queryset = self.get_ordered_queryset(filters, search_value, order, request)
         page = int(start / per_page) + 1
         paginator = Paginator(queryset, per_page)
         data = [x.to_json() for x in paginator.page(page).object_list]
@@ -310,7 +310,8 @@ class Datatables(View):
                 else:
                     order += list_display_column.split('.')[0]
 
-            return JsonResponse(self.get_data(start, per_page, filters, search_value, draw, order), encoder=Codec)
+            return JsonResponse(self.get_data(start, per_page, filters, search_value, draw, order, request),
+                                encoder=Codec)
         if 'open' in request.POST:
             instance = self.model.objects.get(id=int(request.POST.get('id')))
             form = self.get_form()(instance=instance)
